==> nextcloud-31.0.8-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_reminders/l10n/ru.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Напоминания о файлах",
    "Reminder for {name}" : "Напоминание для {name}",
    "View file" : "Просмотреть файл",
    "View folder" : "Просмотреть папку",
    "Set file reminders" : "Установить напоминания о файлах",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣Напоминания о файлах**\n\nУстановите напоминания о файлах.\n\nПримечание: чтобы использовать приложение \"Напоминания о файлах\", убедитесь, что приложение \"Уведомления\" установлено и включено. Приложение \"Уведомления\" предоставляет необходимые API-интерфейсы для правильной работы приложения \"Напоминания о файлах\".",
    "Set reminder for \"{fileName}\"" : "Установить напоминание для \"{fileName}\"",
    "Clear reminder" : "Очистить напоминание",
    "Please choose a valid date & time" : "Пожалуйста, выберите правильную дату и время",
    "Reminder set for \"{fileName}\"" : "Напоминание для \"{fileName}\"",
    "Failed to set reminder" : "Не удалось установить напоминание",
    "Reminder cleared for \"{fileName}\"" : "Напоминание очищено для \"{fileName}\"",
    "Failed to clear reminder" : "Не удалось удалить напоминание",
    "We will remind you of this file" : "Мы напомним вам об этом файле",
    "Cancel" : "Отмена",
    "Set reminder" : "Установить напоминание",
    "Reminder set" : "Установить напоминание",
    "Later today" : "Позже сегодня",
    "Set reminder for later today" : "Установить напоминание позднее сегодня",
    "Tomorrow" : "Завтра",
    "Set reminder for tomorrow" : "Установить напоминание на завтра",
    "This weekend" : "Эта неделя",
    "Set reminder for this weekend" : "Установить напоминание на эти выходные",
    "Next week" : "Следующая неделя",
    "Set reminder for next week" : "Установить напоминание на следующую неделю",
    "Set reminder at custom date & time" : "Установить напоминание на индивидуальную дату и время",
    "Set custom reminder" : "Установить особое напоминание"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_reminders/l10n/ru.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Напоминания о файлах",
    "Reminder for {name}" : "Напоминание для {name}",
    "View file" : "Просмотреть файл",
    "View folder" : "Просмотреть папку",
    "Set file reminders" : "Установить напоминания о файлах",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣Напоминания о файлах**\n\nУстановите напоминания о файлах.\n\nПримечание: чтобы использовать приложение \"Напоминания о файлах\", убедитесь, что приложение \"Уведомления\" установлено и включено. Приложение \"Уведомления\" предоставляет необходимые API-интерфейсы для правильной работы приложения \"Напоминания о файлах\".",
    "Please choose a valid date & time" : "Пожалуйста, выберите правильную дату и время",
    "Reminder set for \"{fileName}\"" : "Напоминание для \"{fileName}\"",
    "Failed to set reminder" : "Не удалось установить напоминание",
    "Reminder cleared for \"{fileName}\"" : "Напоминание очищено для \"{fileName}\"",
    "Failed to clear reminder" : "Не удалось удалить напоминание",
    "Reminder at custom date & time" : "Напоминание в указанную дату и время",
    "We will remind you of this file" : "Мы напомним вам об этом файле",
    "Cancel" : "Отмена",
    "Clear reminder" : "Очистить напоминание",
    "Set reminder" : "Установить напоминание",
    "Reminder set" : "Установить напоминание",
    "Custom reminder" : "Пользовательское напоминание",
    "Later today" : "Позже сегодня",
    "Set reminder for later today" : "Установить напоминание позднее сегодня",
    "Tomorrow" : "Завтра",
    "Set reminder for tomorrow" : "Установить напоминание на завтра",
    "This weekend" : "Эта неделя",
    "Set reminder for this weekend" : "Установить напоминание на эти выходные",
    "Next week" : "Следующая неделя",
    "Set reminder for next week" : "Установить напоминание на следующую неделю",
    "Set reminder for \"{fileName}\"" : "Установить напоминание для \"{fileName}\"",
    "Set reminder at custom date & time" : "Установить напоминание на индивидуальную дату и время",
    "Set custom reminder" : "Установить особое напоминание"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
